==> rrgp-1.0.6.tar.gz: rrgp-1.0.6/README.md <==
# Human Activity Recognition Using Smartphones

[![Build Status](https://travis-ci.org/patrickaudriaz/mini-project.svg?branch=master)](https://travis-ci.org/patrickaudriaz/mini-project)
[![Coverage Status](https://coveralls.io/repos/github/patrickaudriaz/mini-project/badge.svg)](https://coveralls.io/github/patrickaudriaz/mini-project)
[![Generic badge](https://img.shields.io/badge/doc-latest-orange.svg)](https://patrickaudriaz.github.io/mini-project/)
[![GitHub release](https://img.shields.io/github/v/release/patrickaudriaz/mini-project)](https://github.com/patrickaudriaz/mini-project/releases/latest)
[![PyPI version](https://badge.fury.io/py/rrgp.svg)](https://badge.fury.io/py/rrgp)
[![Generic badge](https://img.shields.io/badge/github-project-purple.svg)](https://github.com/patrickaudriaz/mini-project)
[![License: MIT](https://img.shields.io/badge/License-MIT-red.svg)](https://opensource.org/licenses/MIT)


This project aims to train a model to recognise human activities (like walking, 
standing, or sitting) based on accelerometer and gyroscope data collected with 
a smartphone.

For installation and usage instructions, please refer to 
[our documentation](https://patrickaudriaz.github.io/mini-project/).

## Dataset

This package use the "Human Activity Recognition Using Smartphones Data Set".
For more information about it, please refer to the 
[original publication](https://archive.ics.uci.edu/ml/datasets/human+activity+recognition+using+smartphones).

> Davide Anguita, Alessandro Ghio, Luca Oneto, Xavier Parra and Jorge L. Reyes-Ortiz. A Public Domain Dataset for Human Activity Recognition Using Smartphones. 21th European Symposium on Artificial Neural Networks, Computational Intelligence and Machine Learning, ESANN 2013. Bruges, Belgium 24-26 April 2013.

## License

This repository is made publicly available under the [MIT License](https://opensource.org/licenses/MIT).

## Authors 
- [Geoffrey Raposo](https://github.com/ge0ra)
- [Patrick Audriaz](https://patrick-audriaz.com/)

==> rrgp-1.0.7.tar.gz: rrgp-1.0.7/README.md <==
# Human Activity Recognition Using Smartphones

[![Build Status](https://travis-ci.org/patrickaudriaz/mini-project.svg?branch=master)](https://travis-ci.org/patrickaudriaz/mini-project)
[![Coverage Status](https://coveralls.io/repos/github/patrickaudriaz/mini-project/badge.svg)](https://coveralls.io/github/patrickaudriaz/mini-project)
[![Generic badge](https://img.shields.io/badge/doc-latest-orange.svg)](https://patrickaudriaz.github.io/mini-project/)
[![GitHub release](https://img.shields.io/github/v/release/patrickaudriaz/mini-project)](https://github.com/patrickaudriaz/mini-project/releases/latest)
[![PyPI](https://img.shields.io/pypi/v/rrgp)](https://badge.fury.io/py/rrgp)
[![Generic badge](https://img.shields.io/badge/github-project-purple.svg)](https://github.com/patrickaudriaz/mini-project)
[![License: MIT](https://img.shields.io/badge/License-MIT-red.svg)](https://opensource.org/licenses/MIT)


This project aims to train a model to recognise human activities (like walking, 
standing, or sitting) based on accelerometer and gyroscope data collected with 
a smartphone.

For installation and usage instructions, please refer to 
[our documentation](https://patrickaudriaz.github.io/mini-project/).

## Dataset

This package use the "Human Activity Recognition Using Smartphones Data Set".
For more information about it, please refer to the 
[original publication](https://archive.ics.uci.edu/ml/datasets/human+activity+recognition+using+smartphones).

> Davide Anguita, Alessandro Ghio, Luca Oneto, Xavier Parra and Jorge L. Reyes-Ortiz. A Public Domain Dataset for Human Activity Recognition Using Smartphones. 21th European Symposium on Artificial Neural Networks, Computational Intelligence and Machine Learning, ESANN 2013. Bruges, Belgium 24-26 April 2013.

## License

This repository is made publicly available under the [MIT License](https://opensource.org/licenses/MIT).

## Authors 
- [Geoffrey Raposo](https://github.com/ge0ra)
- [Patrick Audriaz](https://patrick-audriaz.com/)
